task delly {

	File tumor_bam
	File tumor_bam_idx
	File normal_bam
	File normal_bam_idx
	File ref_dir
	String fasta
	String sample_name
	String docker
	String disk_size
	String cluster_config

	command <<<

		set -o pipefail
		set -e
		echo -e "${sample_name}.tumor\ttumor\n${sample_name}.normal\tnormal" > samples.tsv

		nt=$(nproc)
		export OMP_NUM_THREADS=$nt

		/opt/delly/src/delly call -n -t DEL -g ${ref_dir}/${fasta} -o ${sample_name}.delly.del.somatic.bcf -x /opt/delly/excludeTemplates/human.hg38.excl.tsv ${tumor_bam} ${normal_bam}

		/opt/delly/src/delly filter -t DEL -f somatic -o ${sample_name}.delly.del.somatic.filtered.bcf -s samples.tsv ${sample_name}.delly.del.somatic.bcf

		/opt/delly/src/delly call -n -t DUP -g ${ref_dir}/${fasta} -o ${sample_name}.delly.dup.somatic.bcf -x /opt/delly/excludeTemplates/human.hg38.excl.tsv ${tumor_bam} ${normal_bam}

		/opt/delly/src/delly filter -t DUP -f somatic -o ${sample_name}.delly.dup.somatic.filtered.bcf -s samples.tsv ${sample_name}.delly.dup.somatic.bcf

		/opt/delly/src/delly call -n -t INS -g ${ref_dir}/${fasta} -o ${sample_name}.delly.ins.somatic.bcf -x /opt/delly/excludeTemplates/human.hg38.excl.tsv ${tumor_bam} ${normal_bam}

		/opt/delly/src/delly filter -t INS -f somatic -o ${sample_name}.delly.ins.somatic.filtered.bcf -s samples.tsv ${sample_name}.delly.ins.somatic.bcf

		/opt/delly/src/delly call -n -t INV -g ${ref_dir}/${fasta} -o ${sample_name}.delly.inv.somatic.bcf -x /opt/delly/excludeTemplates/human.hg38.excl.tsv ${tumor_bam} ${normal_bam}

		/opt/delly/src/delly filter -t INV -f somatic -o ${sample_name}.delly.inv.somatic.filtered.bcf -s samples.tsv ${sample_name}.delly.inv.somatic.bcf

		/opt/delly/src/delly call -n -t BND -g ${ref_dir}/${fasta} -o ${sample_name}.delly.bnd.somatic.bcf -x /opt/delly/excludeTemplates/human.hg38.excl.tsv ${tumor_bam} ${normal_bam}

		/opt/delly/src/delly filter -t BND -f somatic -o ${sample_name}.delly.bnd.somatic.filtered.bcf -s samples.tsv ${sample_name}.delly.bnd.somatic.bcf

		>>>

		runtime {
		docker:docker
    	cluster:cluster_config
    	systemDisk: "cloud_ssd 40"
    	dataDisk: "cloud_ssd " + disk_size + " /cromwell_root/"
	}

	output {
		File del_bcf = "${sample_name}.delly.del.somatic.filtered.bcf"
		File del_bcf_index = "${sample_name}.delly.del.somatic.filtered.bcf.csi"
		File dup_bcf = "${sample_name}.delly.dup.somatic.filtered.bcf"
		File dup_bcf_index = "${sample_name}.delly.dup.somatic.filtered.bcf.csi"
		File ins_bcf = "${sample_name}.delly.ins.somatic.filtered.bcf"
		File ins_bcf_index = "${sample_name}.delly.ins.somatic.filtered.bcf.csi"
		File inv_bcf = "${sample_name}.delly.inv.somatic.filtered.bcf"
		File inv_bcf_index = "${sample_name}.delly.inv.somatic.filtered.bcf.csi"
		File bnd_bcf = "${sample_name}.delly.bnd.somatic.filtered.bcf"
		File bnd_bcf_index = "${sample_name}.delly.bnd.somatic.filtered.bcf.csi"
	}
}




