import "./tasks/mapping.wdl" as mapping
import "./tasks/delly.wdl" as delly
import "./tasks/bcf2vcf.wdl" as bcf2vcf

workflow {{ project_name }} {
	
	String SENTIEON_INSTALL_DIR
	String SENTIEONdocker
	String DELLYdocker
	String BCFdocker

	File tumor_read1
	File tumor_read2
	File normal_read1
	File normal_read2
	File ref_dir
	String fasta
	String sample_name
	String disk_size

	String BIGcluster_config
	String SMALLcluster_config

	call mapping.mapping as tumor_mapping {
		input: 
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		group=sample_name,
		sample=sample_name,
		type="tumor",
		pl="ILLUMINAL",
		fasta=fasta,
		ref_dir=ref_dir,
		fastq_1=tumor_read1,
		fastq_2=tumor_read2,
		docker=SENTIEONdocker,
		disk_size=disk_size,
		cluster_config=BIGcluster_config
	}

	call mapping.mapping as normal_mapping {
		input: 
		SENTIEON_INSTALL_DIR=SENTIEON_INSTALL_DIR,
		group=sample_name,
		sample=sample_name,
		type="normal",
		pl="ILLUMINAL",
		fasta=fasta,
		ref_dir=ref_dir,
		fastq_1=normal_read1,
		fastq_2=normal_read2,
		docker=SENTIEONdocker,
		disk_size=disk_size,
		cluster_config=BIGcluster_config
	}

	
	call delly.delly as delly {
		input: 
		tumor_bam=tumor_mapping.sorted_bam,
		tumor_bam_idx=tumor_mapping.sorted_bam_index,
		normal_bam=normal_mapping.sorted_bam,
		normal_bam_idx=normal_mapping.sorted_bam_index,
		ref_dir=ref_dir,
		fasta=fasta,
		sample_name=sample_name,
		docker=DELLYdocker,
		disk_size=disk_size,
		cluster_config=SMALLcluster_config
	}

	call bcf2vcf.bcf2vcf as bcf2vcf {
		input:
		ins_bcf=delly.ins_bcf,
		ins_bcf_index=delly.ins_bcf_index,
		del_bcf=delly.del_bcf,
		del_bcf_index=delly.del_bcf_index,
		dup_bcf=delly.dup_bcf,
		dup_bcf_index=delly.dup_bcf_index,
		inv_bcf=delly.inv_bcf,
		inv_bcf_index=delly.inv_bcf_index,
		bnd_bcf=delly.bnd_bcf,
		bnd_bcf_index=delly.bnd_bcf_index,
		docker=BCFdocker,
		disk_size=disk_size,
		cluster_config=SMALLcluster_config,
		sample_name=sample_name
	}
}

